@@ -1,6 +1,10 @@
 #ifndef PYTHONQTWRAPPERPLUGIN_H
 #define PYTHONQTWRAPPERPLUGIN_H
 
+#include <Python.h>
+#include <shiboken.h>
+#include <shiboken/conversions.h>
+
 #include <mbarcode-qt/plugininterfaces.h>
 #include <mbarcode-qt/pluginaction.h>
 
@@ -30,6 +34,8 @@ private:
 
     // this is a list of the sinks provided by all the ini files
     QList<PythonQTWrapperSink *> sinks;
+    //PyObject *_compiledClass;
+    //QList<PyObject *> pythonInstances;
 };
 
 #endif // PYTHONQTWRAPPERPLUGIN_H
